# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LlamaParseSupportedFileExtensions(str, enum.Enum):
    """
    An enumeration.
    """

    PDF = ".pdf"
    DOC = ".doc"
    DOCX = ".docx"
    DOCM = ".docm"
    DOT = ".dot"
    DOTX = ".dotx"
    DOTM = ".dotm"
    RTF = ".rtf"
    WPS = ".wps"
    WPD = ".wpd"
    SXW = ".sxw"
    STW = ".stw"
    SXG = ".sxg"
    PAGES = ".pages"
    MW = ".mw"
    MCW = ".mcw"
    UOT = ".uot"
    UOF = ".uof"
    UOS = ".uos"
    UOP = ".uop"
    PPT = ".ppt"
    PPTX = ".pptx"
    POT = ".pot"
    PPTM = ".pptm"
    POTX = ".potx"
    POTM = ".potm"
    KEY = ".key"
    ODP = ".odp"
    ODG = ".odg"
    OTP = ".otp"
    FOPD = ".fopd"
    SXI = ".sxi"
    STI = ".sti"
    EPUB = ".epub"

    def visit(
        self,
        pdf: typing.Callable[[], T_Result],
        doc: typing.Callable[[], T_Result],
        docx: typing.Callable[[], T_Result],
        docm: typing.Callable[[], T_Result],
        dot: typing.Callable[[], T_Result],
        dotx: typing.Callable[[], T_Result],
        dotm: typing.Callable[[], T_Result],
        rtf: typing.Callable[[], T_Result],
        wps: typing.Callable[[], T_Result],
        wpd: typing.Callable[[], T_Result],
        sxw: typing.Callable[[], T_Result],
        stw: typing.Callable[[], T_Result],
        sxg: typing.Callable[[], T_Result],
        pages: typing.Callable[[], T_Result],
        mw: typing.Callable[[], T_Result],
        mcw: typing.Callable[[], T_Result],
        uot: typing.Callable[[], T_Result],
        uof: typing.Callable[[], T_Result],
        uos: typing.Callable[[], T_Result],
        uop: typing.Callable[[], T_Result],
        ppt: typing.Callable[[], T_Result],
        pptx: typing.Callable[[], T_Result],
        pot: typing.Callable[[], T_Result],
        pptm: typing.Callable[[], T_Result],
        potx: typing.Callable[[], T_Result],
        potm: typing.Callable[[], T_Result],
        key: typing.Callable[[], T_Result],
        odp: typing.Callable[[], T_Result],
        odg: typing.Callable[[], T_Result],
        otp: typing.Callable[[], T_Result],
        fopd: typing.Callable[[], T_Result],
        sxi: typing.Callable[[], T_Result],
        sti: typing.Callable[[], T_Result],
        epub: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LlamaParseSupportedFileExtensions.PDF:
            return pdf()
        if self is LlamaParseSupportedFileExtensions.DOC:
            return doc()
        if self is LlamaParseSupportedFileExtensions.DOCX:
            return docx()
        if self is LlamaParseSupportedFileExtensions.DOCM:
            return docm()
        if self is LlamaParseSupportedFileExtensions.DOT:
            return dot()
        if self is LlamaParseSupportedFileExtensions.DOTX:
            return dotx()
        if self is LlamaParseSupportedFileExtensions.DOTM:
            return dotm()
        if self is LlamaParseSupportedFileExtensions.RTF:
            return rtf()
        if self is LlamaParseSupportedFileExtensions.WPS:
            return wps()
        if self is LlamaParseSupportedFileExtensions.WPD:
            return wpd()
        if self is LlamaParseSupportedFileExtensions.SXW:
            return sxw()
        if self is LlamaParseSupportedFileExtensions.STW:
            return stw()
        if self is LlamaParseSupportedFileExtensions.SXG:
            return sxg()
        if self is LlamaParseSupportedFileExtensions.PAGES:
            return pages()
        if self is LlamaParseSupportedFileExtensions.MW:
            return mw()
        if self is LlamaParseSupportedFileExtensions.MCW:
            return mcw()
        if self is LlamaParseSupportedFileExtensions.UOT:
            return uot()
        if self is LlamaParseSupportedFileExtensions.UOF:
            return uof()
        if self is LlamaParseSupportedFileExtensions.UOS:
            return uos()
        if self is LlamaParseSupportedFileExtensions.UOP:
            return uop()
        if self is LlamaParseSupportedFileExtensions.PPT:
            return ppt()
        if self is LlamaParseSupportedFileExtensions.PPTX:
            return pptx()
        if self is LlamaParseSupportedFileExtensions.POT:
            return pot()
        if self is LlamaParseSupportedFileExtensions.PPTM:
            return pptm()
        if self is LlamaParseSupportedFileExtensions.POTX:
            return potx()
        if self is LlamaParseSupportedFileExtensions.POTM:
            return potm()
        if self is LlamaParseSupportedFileExtensions.KEY:
            return key()
        if self is LlamaParseSupportedFileExtensions.ODP:
            return odp()
        if self is LlamaParseSupportedFileExtensions.ODG:
            return odg()
        if self is LlamaParseSupportedFileExtensions.OTP:
            return otp()
        if self is LlamaParseSupportedFileExtensions.FOPD:
            return fopd()
        if self is LlamaParseSupportedFileExtensions.SXI:
            return sxi()
        if self is LlamaParseSupportedFileExtensions.STI:
            return sti()
        if self is LlamaParseSupportedFileExtensions.EPUB:
            return epub()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .google_drive_reader_file_extractor_value import GoogleDriveReaderFileExtractorValue

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class GoogleDriveReader(pydantic.BaseModel):
    """
    Google Drive Reader.

    Reads files from Google Drive. Credentials passed directly to the constructor
    will take precedence over those passed as file paths.

    Args:
    drive_id (Optional[str]): Drive id of the shared drive in google drive.
    folder_id (Optional[str]): Folder id of the folder in google drive.
    file_ids (Optional[str]): File ids of the files in google drive.
    query_string: A more generic query string to filter the documents, e.g. "name contains 'test'".
    It gives more flexibility to filter the documents. More info: https://developers.google.com/drive/api/v3/search-files
    is_cloud (Optional[bool]): Whether the reader is being used in
    a cloud environment. Will not save credentials to disk if so.
    Defaults to False.
    credentials_path (Optional[str]): Path to client config file.
    Defaults to None.
    token_path (Optional[str]): Path to authorized user info file. Defaults
    to None.
    service_account_key_path (Optional[str]): Path to service account key
    file. Defaults to None.
    client_config (Optional[dict]): Dictionary containing client config.
    Defaults to None.
    authorized_user_info (Optional[dict]): Dicstionary containing authorized
    user info. Defaults to None.
    service_account_key (Optional[dict]): Dictionary containing service
    account key. Defaults to None.
    file_extractor (Optional[Dict[str, BaseReader]]): A mapping of file
    extension to a BaseReader class that specifies how to convert that
    file to text. See `SimpleDirectoryReader` for more details.
    """

    is_remote: typing.Optional[bool] = pydantic.Field(
        description="Whether the data is loaded from a remote API or a local file."
    )
    drive_id: typing.Optional[str]
    folder_id: typing.Optional[str]
    file_ids: typing.Optional[typing.List[str]]
    query_string: typing.Optional[str]
    client_config: typing.Optional[typing.Dict[str, typing.Any]]
    authorized_user_info: typing.Optional[typing.Dict[str, typing.Any]]
    service_account_key: typing.Optional[typing.Dict[str, typing.Any]]
    token_path: typing.Optional[str]
    file_extractor: typing.Optional[typing.Dict[str, GoogleDriveReaderFileExtractorValue]]
    class_name: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class SimpleFileNodeParser(pydantic.BaseModel):
    """
    Simple file node parser.

    Splits a document loaded from a file into Nodes using logic based on the file type
    automatically detects the NodeParser to use based on file type

    Args:
    include_metadata (bool): whether to include metadata in nodes
    include_prev_next_rel (bool): whether to include prev/next relationships
    """

    include_metadata: typing.Optional[bool] = pydantic.Field(
        description="Whether or not to consider metadata when splitting."
    )
    include_prev_next_rel: typing.Optional[bool] = pydantic.Field(description="Include prev/next node relationships.")
    callback_manager: typing.Optional[typing.Dict[str, typing.Any]]
    class_name: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing

from .cloud_chroma_vector_store import CloudChromaVectorStore
from .cloud_pinecone_vector_store import CloudPineconeVectorStore
from .cloud_postgres_vector_store import CloudPostgresVectorStore
from .cloud_qdrant_vector_store import CloudQdrantVectorStore
from .cloud_weaviate_vector_store import CloudWeaviateVectorStore

DataSinkComponentOne = typing.Union[
    CloudChromaVectorStore,
    CloudPineconeVectorStore,
    CloudPostgresVectorStore,
    CloudQdrantVectorStore,
    CloudWeaviateVectorStore,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .one_drive_reader_file_extractor_value import OneDriveReaderFileExtractorValue

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class OneDriveReader(pydantic.BaseModel):
    """
    Microsoft OneDrive reader.

    Initializes a new instance of the OneDriveReader.

    :param client_id: The Application (client) ID for the app registered in the Azure Entra (formerly Azure Active directory) portal with MS Graph permission "Files.Read.All".
    :param tenant_id: The Directory (tenant) ID of the Azure Active Directory (AAD) tenant the app is registered with.
    Defaults to "consumers" for multi-tenant applications and OneDrive personal.
    :param client_secret: The Application Secret for the app registered in the Azure portal.
    If provided, the MSAL client credential flow will be used for authentication (ConfidentialClientApplication).
    If not provided, interactive authentication will be used (Not recommended for CI/CD or scenarios where manual interaction for authentication is not feasible).
    Required for App authentication.
    :param userprinciplename: The user principal name (normally organization provided email) whose OneDrive will be accessed. Required for App authentication. Will be used if the
    parameter is not provided when calling load_data().
    :param folder_id: The folder ID of the folder to fetch from OneDrive. Will be used if the parameter is not provided when calling load_data().
    :param file_ids: A list of file IDs of files to fetch from OneDrive. Will be used if the parameter is not provided when calling load_data().
    :param folder_path (str, optional): The relative path of the OneDrive folder to download. If provided, files within the folder are downloaded. Will be used if the parameter is
    not provided when calling load_data().
    :param file_paths (List[str], optional): List of specific file paths to download. Will be used if the parameter is not provided when calling load_data().
    :param file_extractor (Optional[Dict[str, BaseReader]]): A mapping of file extension to a BaseReader class that specifies how to convert that file to text.
    See `SimpleDirectoryReader` for more details.

    For interactive authentication to work, a browser is used to authenticate, hence the registered application should have a redirect URI set to 'https://localhost'
    for mobile and native applications.
    """

    is_remote: typing.Optional[bool] = pydantic.Field(
        description="Whether the data is loaded from a remote API or a local file."
    )
    client_id: str
    client_secret: typing.Optional[str]
    tenant_id: typing.Optional[str]
    userprincipalname: typing.Optional[str]
    folder_id: typing.Optional[str]
    file_ids: typing.Optional[typing.List[str]]
    folder_path: typing.Optional[str]
    file_paths: typing.Optional[typing.List[str]]
    file_extractor: typing.Optional[typing.Dict[str, OneDriveReaderFileExtractorValue]]
    class_name: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .configured_transformation_item import ConfiguredTransformationItem
from .data_sink_create import DataSinkCreate
from .data_source_create import DataSourceCreate
from .eval_execution_params import EvalExecutionParams
from .pipeline_type import PipelineType
from .preset_retrieval_params import PresetRetrievalParams

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class PipelineCreate(pydantic.BaseModel):
    """
    Schema for creating a pipeline.
    """

    configured_transformations: typing.Optional[typing.List[ConfiguredTransformationItem]] = pydantic.Field(
        description="List of configured transformations."
    )
    data_source_ids: typing.Optional[typing.List[str]] = pydantic.Field(
        description="List of data source IDs. When provided instead of data_sources, the data sources will be looked up by ID."
    )
    data_sources: typing.Optional[typing.List[DataSourceCreate]] = pydantic.Field(
        description="List of data sources. When provided instead of data_source_ids, the data sources will be created."
    )
    data_sink_ids: typing.Optional[typing.List[str]] = pydantic.Field(
        description="List of data sink IDs. When provided instead of data_sinks, the data sinks will be looked up by ID."
    )
    data_sinks: typing.Optional[typing.List[DataSinkCreate]] = pydantic.Field(
        description="List of data sinks. When provided instead of data_sink_ids, the data sinks will be created."
    )
    raw_file_names: typing.Optional[typing.List[str]] = pydantic.Field(
        description="List of raw file names to be used as pipeline inputs."
    )
    preset_retrieval_parameters: typing.Optional[PresetRetrievalParams] = pydantic.Field(
        description="Preset retrieval parameters for the pipeline."
    )
    eval_parameters: typing.Optional[EvalExecutionParams] = pydantic.Field(
        description="Eval parameters for the pipeline."
    )
    llama_parse_enabled: typing.Optional[bool] = pydantic.Field(
        description="Whether to use LlamaParse during pipeline execution."
    )
    name: str
    pipeline_type: typing.Optional[PipelineType] = pydantic.Field(
        description="Type of pipeline. Either PLAYGROUND or MANAGED."
    )
    managed_pipeline_id: typing.Optional[str] = pydantic.Field(
        description="The ID of the ManagedPipeline this playground pipeline is linked to."
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.cloud_chroma_vector_store import CloudChromaVectorStore
from ....types.cloud_pinecone_vector_store import CloudPineconeVectorStore
from ....types.cloud_postgres_vector_store import CloudPostgresVectorStore
from ....types.cloud_qdrant_vector_store import CloudQdrantVectorStore
from ....types.cloud_weaviate_vector_store import CloudWeaviateVectorStore

DataSinkUpdateComponentOne = typing.Union[
    CloudChromaVectorStore,
    CloudPineconeVectorStore,
    CloudPostgresVectorStore,
    CloudQdrantVectorStore,
    CloudWeaviateVectorStore,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .az_storage_blob_reader_file_extractor_value import AzStorageBlobReaderFileExtractorValue

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class AzStorageBlobReader(pydantic.BaseModel):
    """
    General reader for any Azure Storage Blob file or directory.

    Args:
    container_name (str): name of the container for the blob.
    blob (Optional[str]): name of the file to download. If none specified
    this loader will iterate through list of blobs in the container.
    name_starts_with (Optional[str]): filter the list of blobs to download
    to only those whose names begin with the specified string.
    include: (Union[str, List[str], None]): Specifies one or more additional
    datasets to include in the response. Options include: 'snapshots',
    'metadata', 'uncommittedblobs', 'copy', 'deleted',
    'deletedwithversions', 'tags', 'versions', 'immutabilitypolicy',
    'legalhold'.
    file_extractor (Optional[Dict[str, Union[str, BaseReader]]]): A mapping of file
    extension to a BaseReader class that specifies how to convert that file
    to text. See `SimpleDirectoryReader` for more details, or call this path `llama_index.readers.file.base.DEFAULT_FILE_READER_CLS`.
    connection_string (str): A connection string which can be found under a storage account's "Access keys" security tab. This parameter
    can be used in place of both the account URL and credential.
    account_url (str): URI to the storage account, may include SAS token.
    credential (Union[str, Dict[str, str], AzureNamedKeyCredential, AzureSasCredential, TokenCredential, None] = None):
    The credentials with which to authenticate. This is optional if the account URL already has a SAS token.
    """

    is_remote: typing.Optional[bool]
    container_name: str
    prefix: typing.Optional[str]
    blob: typing.Optional[str]
    name_starts_with: typing.Optional[str]
    include: typing.Optional[typing.Any]
    file_extractor: typing.Optional[typing.Dict[str, AzStorageBlobReaderFileExtractorValue]]
    connection_string: typing.Optional[str]
    account_url: typing.Optional[str]
    credential: typing.Optional[typing.Any]
    class_name: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class CloudPostgresVectorStore(pydantic.BaseModel):
    """
    Base class for cloud vector stores.
    """

    connection_string: str
    async_connection_string: str
    table_name: str
    schema_name: str
    embed_dim: int
    hybrid_search: bool
    text_search_config: str
    cache_ok: bool
    perform_setup: bool
    debug: bool
    use_jsonb: bool
    class_name: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .llm import Llm
from .node_parser import NodeParser

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class MarkdownElementNodeParser(pydantic.BaseModel):
    """
    Markdown element node parser.

    Splits a markdown document into Text Nodes and Index Nodes corresponding to embedded objects
    (e.g. tables).
    """

    include_metadata: typing.Optional[bool] = pydantic.Field(
        description="Whether or not to consider metadata when splitting."
    )
    include_prev_next_rel: typing.Optional[bool] = pydantic.Field(description="Include prev/next node relationships.")
    callback_manager: typing.Optional[typing.Dict[str, typing.Any]]
    llm: typing.Optional[Llm] = pydantic.Field(description="LLM model to use for summarization.")
    summary_query_str: typing.Optional[str] = pydantic.Field(description="Query string to use for summarization.")
    num_workers: typing.Optional[int] = pydantic.Field(description="Num of workers for async jobs.")
    show_progress: typing.Optional[bool] = pydantic.Field(description="Whether to show progress.")
    nested_node_parser: typing.Optional[NodeParser] = pydantic.Field(
        description="Other types of node parsers to handle some types of nodes."
    )
    class_name: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.document import Document
from ....types.reader_config import ReaderConfig
from ....types.text_node import TextNode

DataSourceUpdateComponentOne = typing.Union[ReaderConfig, typing.Any, TextNode, Document]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .share_point_reader_file_extractor_value import SharePointReaderFileExtractorValue

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class SharePointReader(pydantic.BaseModel):
    """
    SharePoint reader.

    Reads folders from the SharePoint site from a folder under documents.

    Args:
    client_id (str): The Application ID for the app registered in Microsoft Azure Portal.
    The application must also be configured with MS Graph permissions "Files.ReadAll", "Sites.ReadAll" and BrowserSiteLists.Read.All.
    client_secret (str): The application secret for the app registered in Azure.
    tenant_id (str): Unique identifier of the Azure Active Directory Instance.
    sharepoint_site_name (Optional[str]): The name of the SharePoint site to download from.
    sharepoint_folder_path (Optional[str]): The path of the SharePoint folder to download from.
    sharepoint_folder_id (Optional[str]): The ID of the SharePoint folder to download from. Overrides sharepoint_folder_path.
    file_extractor (Optional[Dict[str, BaseReader]]): A mapping of file extension to a BaseReader class that specifies how to convert that
    file to text. See `SimpleDirectoryReader` for more details.
    """

    is_remote: typing.Optional[bool] = pydantic.Field(
        description="Whether the data is loaded from a remote API or a local file."
    )
    client_id: typing.Optional[str]
    client_secret: typing.Optional[str]
    tenant_id: typing.Optional[str]
    sharepoint_site_name: typing.Optional[str]
    sharepoint_folder_path: typing.Optional[str]
    sharepoint_folder_id: typing.Optional[str]
    file_extractor: typing.Optional[typing.Dict[str, SharePointReaderFileExtractorValue]]
    class_name: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...core.remove_none_from_dict import remove_none_from_dict
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.http_validation_error import HttpValidationError

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class BillingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_checkout_session(self, *, success_url: str, cancel_url: str) -> str:
        """
        Create a new checkout session.

        Parameters:
            - success_url: str.

            - cancel_url: str.
        ---
        from platform.client import PlatformApi

        client = PlatformApi(
            token="YOUR_TOKEN",
            base_url="https://yourhost.com/path/to/api",
        )
        client.billing.create_checkout_session(
            success_url="string",
            cancel_url="string",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "api/billing/checkout-session"),
            json=jsonable_encoder({"success_url": success_url, "cancel_url": cancel_url}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(str, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(HttpValidationError, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create_customer_portal_session(self, *, return_url: str) -> str:
        """
        Create a new customer portal session.

        Parameters:
            - return_url: str.
        ---
        from platform.client import PlatformApi

        client = PlatformApi(
            token="YOUR_TOKEN",
            base_url="https://yourhost.com/path/to/api",
        )
        client.billing.create_customer_portal_session(
            return_url="string",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "api/billing/customer-portal-session"),
            json=jsonable_encoder({"return_url": return_url}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(str, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(HttpValidationError, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def stripe_webhook(self, *, stripe_signature: typing.Optional[str] = None) -> typing.Any:
        """
        Stripe webhook endpoint.

        Parameters:
            - stripe_signature: typing.Optional[str].
        ---
        from platform.client import PlatformApi

        client = PlatformApi(
            token="YOUR_TOKEN",
            base_url="https://yourhost.com/path/to/api",
        )
        client.billing.stripe_webhook()
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "api/billing/webhook"),
            headers=remove_none_from_dict({**self._client_wrapper.get_headers(), "stripe-signature": stripe_signature}),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.Any, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(HttpValidationError, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncBillingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_checkout_session(self, *, success_url: str, cancel_url: str) -> str:
        """
        Create a new checkout session.

        Parameters:
            - success_url: str.

            - cancel_url: str.
        ---
        from platform.client import AsyncPlatformApi

        client = AsyncPlatformApi(
            token="YOUR_TOKEN",
            base_url="https://yourhost.com/path/to/api",
        )
        await client.billing.create_checkout_session(
            success_url="string",
            cancel_url="string",
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "api/billing/checkout-session"),
            json=jsonable_encoder({"success_url": success_url, "cancel_url": cancel_url}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(str, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(HttpValidationError, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create_customer_portal_session(self, *, return_url: str) -> str:
        """
        Create a new customer portal session.

        Parameters:
            - return_url: str.
        ---
        from platform.client import AsyncPlatformApi

        client = AsyncPlatformApi(
            token="YOUR_TOKEN",
            base_url="https://yourhost.com/path/to/api",
        )
        await client.billing.create_customer_portal_session(
            return_url="string",
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "api/billing/customer-portal-session"),
            json=jsonable_encoder({"return_url": return_url}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(str, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(HttpValidationError, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def stripe_webhook(self, *, stripe_signature: typing.Optional[str] = None) -> typing.Any:
        """
        Stripe webhook endpoint.

        Parameters:
            - stripe_signature: typing.Optional[str].
        ---
        from platform.client import AsyncPlatformApi

        client = AsyncPlatformApi(
            token="YOUR_TOKEN",
            base_url="https://yourhost.com/path/to/api",
        )
        await client.billing.stripe_webhook()
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "api/billing/webhook"),
            headers=remove_none_from_dict({**self._client_wrapper.get_headers(), "stripe-signature": stripe_signature}),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.Any, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(HttpValidationError, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .s_3_reader_file_extractor_value import S3ReaderFileExtractorValue

try:
    import pydantic
    if pydantic.__version__.startswith("1."):
        raise ImportError
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class S3Reader(pydantic.BaseModel):
    """
    General reader for any S3 file or directory.

    If key is not set, the entire bucket (filtered by prefix) is parsed.

    Args:
    bucket (str): the name of your S3 bucket
    key (Optional[str]): the name of the specific file. If none is provided,
    this loader will iterate through the entire bucket.
    prefix (Optional[str]): the prefix to filter by in the case that the loader
    iterates through the entire bucket. Defaults to empty string.
    recursive (bool): Whether to recursively search in subdirectories.
    True by default.
    file_extractor (Optional[Dict[str, BaseReader]]): A mapping of file
    extension to a BaseReader class that specifies how to convert that file
    to text. See `SimpleDirectoryReader` for more details.
    required_exts (Optional[List[str]]): List of required extensions.
    Default is None.
    num_files_limit (Optional[int]): Maximum number of files to read.
    Default is None.
    file_metadata (Optional[Callable[str, Dict]]): A function that takes
    in a filename and returns a Dict of metadata for the Document.
    Default is None.
    aws_access_id (Optional[str]): provide AWS access key directly.
    aws_access_secret (Optional[str]): provide AWS access key directly.
    s3_endpoint_url (Optional[str]): provide S3 endpoint URL directly.
    """

    is_remote: typing.Optional[bool]
    bucket: str
    key: typing.Optional[str]
    prefix: typing.Optional[str]
    recursive: typing.Optional[bool]
    file_extractor: typing.Optional[typing.Dict[str, S3ReaderFileExtractorValue]]
    required_exts: typing.Optional[typing.List[str]]
    filename_as_id: typing.Optional[bool]
    num_files_limit: typing.Optional[int]
    aws_access_id: typing.Optional[str]
    aws_access_secret: typing.Optional[str]
    aws_session_token: typing.Optional[str]
    s_3_endpoint_url: typing.Optional[str] = pydantic.Field(alias="s3_endpoint_url")
    custom_reader_path: typing.Optional[str]
    class_name: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        json_encoders = {dt.datetime: serialize_datetime}
